@@ -183,7 +183,7 @@ class QuickbooksCore(SitesCore):
                     f'No_customer_{datetime.now().strftime("%H_%M_%S")}.png'
                 )
             )
-            self.send_message_service_type_not_found(customer, first_row.manager)
+            self.send_message_service_type_not_found(first_row.manager, customer)
             return False, '', ''
 
         index: int = 1
@@ -211,7 +211,7 @@ class QuickbooksCore(SitesCore):
                             f'No_service_{datetime.now().strftime("%H_%M_%S")}.png'
                         )
                     )
-                    self.send_message_service_type_not_found(service, first_row.manager)
+                    self.send_message_service_type_not_found(first_row.manager, service)
                     return False, '', ''
                 else:
                     self.browser.click_element_when_visible(f'//div/span/b[text()="{service}"]')
